# TODO: Event types that need to be supported: submitted, executing, terminated
# TODO: Log to file
import subprocess
from pathlib import Path
from typing import NamedTuple, List, Dict
from collections import namedtuple


class Job:
    """
    Class representing a faked HTCondor job
    """

    def __init__(self, file: Path):
        self.fields, self.command = self.parse(file)

    def parse(self, file: Path) -> NamedTuple:
        """
        Parse condor job file for relevant fields
        :param file: Path to job file
        :return: NamedTuple of job data
        """
        # Parse file looking for executable and arguments
        JobData = namedtuple("JobData", ["field_data", "command"])
        section_sep = "\n\n"
        field_sep = "\n"

        with open(file, "r") as f:
            # Split file into data and action sections
            data, command = f.read().split(section_sep)
            fields = data.split(field_sep)
            field_dict = self.parse_fields(fields)
            return JobData(field_dict, command)

    @staticmethod
    def parse_fields(fields: List[str]) -> Dict[str, str]:
        """
        Take in list of fields parsed from input file and return them as a dictionary
        :param fields: List of fields
        :return: Dictionary of fields
        """
        field_dict = {}
        for field in fields:
            key, value = field.split(" = ")
            field_dict[key] = value
        return field_dict

    def execute(self):
        subprocess.run([self.fields['executable'], self.fields['arguments']])


class Dag:
    @staticmethod
    def parse(file):
        dag = Dag()
        # do something here to iterate the file contents and parse it
        raise NotImplementedError

    def execute(self):
        raise NotImplementedError
